summaryrefslogtreecommitdiff
path: root/tools/coq-inferior.el
diff options
context:
space:
mode:
Diffstat (limited to 'tools/coq-inferior.el')
-rw-r--r--tools/coq-inferior.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/tools/coq-inferior.el b/tools/coq-inferior.el
index d4f96a16..b79d97d6 100644
--- a/tools/coq-inferior.el
+++ b/tools/coq-inferior.el
@@ -46,13 +46,13 @@
;;; Installation:
;; You need to have coq.el already installed (it comes with the
;; standard Coq distribution) in order to use this code. Put this
;; file somewhere in you load-path and add the following lines in your
;; "~/.emacs":
;;
;; (setq auto-mode-alist (cons '("\\.v$" . coq-mode) auto-mode-alist))
;; (autoload 'coq-mode "coq" "Major mode for editing Coq vernacular." t)
;; (autoload 'run-coq "inferior-coq" "Run an inferior Coq process." t)
;; (autoload 'run-coq-other-window "inferior-coq"
;; "Run an inferior Coq process in a new window." t)
@@ -78,7 +78,7 @@
;; From -0.0 to 1.0 brought into existence.
-(require 'coq)
+(require 'gallina)
(require 'comint)
(setq coq-program-name "coqtop")
@@ -46,13 +46,13 @@
;;; Installation:
-;; You need to have coq.el already installed (it comes with the
+;; You need to have gallina.el already installed (it comes with the
;; standard Coq distribution) in order to use this code. Put this
;; file somewhere in you load-path and add the following lines in your
@@ -46,13 +46,13 @@
;;
;; (setq auto-mode-alist (cons '("\\.v$" . coq-mode) auto-mode-alist))
-;; (autoload 'coq-mode "coq" "Major mode for editing Coq vernacular." t)
+;; (autoload 'coq-mode "gallina" "Major mode for editing Coq vernacular." t)
;; (autoload 'run-coq "inferior-coq" "Run an inferior Coq process." t)
;; (autoload 'run-coq-other-window "inferior-coq"